@@ -3,23 +3,26 @@ package cmd
 import (
 	"fmt"
 	"os"
+	"path/filepath"
 	"runtime"
 	"time"
 
 	"github.com/apex/log"
 	"github.com/caarlos0/ctrlc"
 	"github.com/fatih/color"
+	"github.com/goreleaser/goreleaser/internal/artifact"
+	"github.com/goreleaser/goreleaser/internal/gio"
 	"github.com/goreleaser/goreleaser/internal/middleware/errhandler"
 	"github.com/goreleaser/goreleaser/internal/middleware/logging"
 	"github.com/goreleaser/goreleaser/internal/middleware/skip"
 	"github.com/goreleaser/goreleaser/internal/pipeline"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
-	"github.com/spf13/cobra"
+	"github.com/muesli/coral"
 )
 
 type buildCmd struct {
-	cmd  *cobra.Command
+	cmd  *coral.Command
 	opts buildOpts
 }
 
@@ -34,12 +37,13 @@ type buildOpts struct {
 	parallelism   int
 	timeout       time.Duration
 	singleTarget  bool
+	output        string
 }
 
 func newBuildCmd() *buildCmd {
 	root := &buildCmd{}
 	// nolint: dupl
-	cmd := &cobra.Command{
+	cmd := &coral.Command{
 		Use:     "build",
 		Aliases: []string{"b"},
 		Short:   "Builds the current project",
@@ -60,8 +64,8 @@ defaulting to the current's machine target if not set.
 `,
 		SilenceUsage:  true,
 		SilenceErrors: true,
-		Args:          cobra.NoArgs,
-		RunE: func(cmd *cobra.Command, args []string) error {
+		Args:          coral.NoArgs,
+		RunE: func(cmd *coral.Command, args []string) error {
 			start := time.Now()
 
 			log.Infof(color.New(color.Bold).Sprint("building..."))
@@ -90,6 +94,7 @@ defaulting to the current's machine target if not set.
 	cmd.Flags().BoolVar(&root.opts.singleTarget, "single-target", false, "Builds only for current GOOS and GOARCH")
 	cmd.Flags().StringVar(&root.opts.id, "id", "", "Builds only the specified build id")
 	cmd.Flags().BoolVar(&root.opts.deprecated, "deprecated", false, "Force print the deprecation message - tests only")
+	cmd.Flags().StringVarP(&root.opts.output, "output", "o", "", "Path to the binary, defaults to the distribution folder according to configs. Only taked into account when using --single-target and a single id (either with --id or if config only has one build)")
 	_ = cmd.Flags().MarkHidden("deprecated")
 
 	root.cmd = cmd
@@ -107,7 +112,7 @@ func buildProject(options buildOpts) (*context.Context, error) {
 		return nil, err
 	}
 	return ctx, ctrlc.Default.Run(ctx, func() error {
-		for _, pipe := range pipeline.BuildCmdPipeline {
+		for _, pipe := range setupPipeline(ctx, options) {
 			if err := skip.Maybe(
 				pipe,
 				logging.Log(
@@ -123,6 +128,13 @@ func buildProject(options buildOpts) (*context.Context, error) {
 	})
 }
 
+func setupPipeline(ctx *context.Context, options buildOpts) []pipeline.Piper {
+	if options.singleTarget && (options.id != "" || len(ctx.Config.Builds) == 1) {
+		return append(pipeline.BuildCmdPipeline, withOutputPipe{options.output})
+	}
+	return pipeline.BuildCmdPipeline
+}
+
 func setupBuildContext(ctx *context.Context, options buildOpts) error {
 	ctx.Parallelism = runtime.NumCPU()
 	if options.parallelism > 0 {
@@ -191,3 +203,21 @@ func setupBuildID(ctx *context.Context, id string) error {
 	ctx.Config.Builds = keep
 	return nil
 }
+
+// withOutputPipe copies the binary from dist to the specified output path.
+type withOutputPipe struct {
+	output string
+}
+
+func (w withOutputPipe) String() string {
+	return fmt.Sprintf("copying binary to %q", w.output)
+}
+
+func (w withOutputPipe) Run(ctx *context.Context) error {
+	path := ctx.Artifacts.Filter(artifact.ByType(artifact.Binary)).List()[0].Path
+	out := w.output
+	if out == "" {
+		out = filepath.Base(path)
+	}
+	return gio.Copy(path, out)
+}
