@@ -331,6 +331,12 @@ func TestInvalidTemplate(t *testing.T) {
 		require.Contains(t, Pipe{}.Run(ctx).Error(), `template: tmpl:1:3: executing "tmpl" at <.NOPE_DESC>: map has no entry for key "NOPE_DESC"`)
 	})
 
+	t.Run("maintainer", func(t *testing.T) {
+		ctx := makeCtx()
+		ctx.Config.NFPMs[0].Maintainer = "{{ .NOPE_DESC }}"
+		require.Contains(t, Pipe{}.Run(ctx).Error(), `template: tmpl:1:3: executing "tmpl" at <.NOPE_DESC>: map has no entry for key "NOPE_DESC"`)
+	})
+
 	t.Run("homepage", func(t *testing.T) {
 		ctx := makeCtx()
 		ctx.Config.NFPMs[0].Homepage = "{{ .NOPE_HOMEPAGE }}"
@@ -592,6 +598,10 @@ func TestDebSpecificConfig(t *testing.T) {
 						Signature: config.NFPMDebSignature{
 							KeyFile: "./testdata/privkey.gpg",
 						},
+						Lintian: []string{
+							"statically-linked-binary",
+							"changelog-file-missing-in-native-package",
+						},
 					},
 				},
 			},
@@ -627,6 +637,10 @@ func TestDebSpecificConfig(t *testing.T) {
 			"NFPM_SOMEID_PASSPHRASE": "hunter2",
 		}
 		require.NoError(t, Pipe{}.Run(ctx))
+
+		bts, err := os.ReadFile(filepath.Join(dist, "deb/foo/.lintian"))
+		require.NoError(t, err)
+		require.Equal(t, "foo: statically-linked-binary\nfoo: changelog-file-missing-in-native-package", string(bts))
 	})
 
 	t.Run("packager specific passphrase set", func(t *testing.T) {
@@ -1148,6 +1162,7 @@ func TestBinDirTemplating(t *testing.T) {
 		Env: []string{
 			"PRO=pro",
 			"DESC=templates",
+			"MAINTAINER=me@me",
 		},
 		NFPMs: []config.NFPM{
 			{
@@ -1160,7 +1175,7 @@ func TestBinDirTemplating(t *testing.T) {
 				Priority:    "standard",
 				Description: "Some description with {{ .Env.DESC }}",
 				License:     "MIT",
-				Maintainer:  "me@me",
+				Maintainer:  "{{ .Env.MAINTAINER }}",
 				Vendor:      "asdf",
 				Homepage:    "https://goreleaser.com/{{ .Env.PRO }}",
 				NFPMOverridables: config.NFPMOverridables{
