@@ -18,23 +18,24 @@ func TestPipeDescription(t *testing.T) {
 	require.NotEmpty(t, Pipe{}.String())
 }
 
+func createTmpFile(tb testing.TB, folder, path string) string {
+	tb.Helper()
+	f, err := os.Create(filepath.Join(folder, path))
+	require.NoError(tb, err)
+	require.NoError(tb, f.Close())
+	return f.Name()
+}
+
 func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 	folder := t.TempDir()
-	tarfile, err := os.Create(filepath.Join(folder, "bin.tar.gz"))
-	require.NoError(t, err)
-	require.NoError(t, tarfile.Close())
-	srcfile, err := os.Create(filepath.Join(folder, "source.tar.gz"))
-	require.NoError(t, err)
-	require.NoError(t, srcfile.Close())
-	debfile, err := os.Create(filepath.Join(folder, "bin.deb"))
-	require.NoError(t, err)
-	require.NoError(t, debfile.Close())
-	filteredtarfile, err := os.Create(filepath.Join(folder, "filtered.tar.gz"))
-	require.NoError(t, err)
-	require.NoError(t, filteredtarfile.Close())
-	filtereddebfile, err := os.Create(filepath.Join(folder, "filtered.deb"))
-	require.NoError(t, err)
-	require.NoError(t, filtereddebfile.Close())
+	tarfile := createTmpFile(t, folder, "bin.tar.gz")
+	srcfile := createTmpFile(t, folder, "source.tar.gz")
+	debfile := createTmpFile(t, folder, "bin.deb")
+	checksumfile := createTmpFile(t, folder, "checksum")
+	checksumsigfile := createTmpFile(t, folder, "checksum.sig")
+	checksumpemfile := createTmpFile(t, folder, "checksum.pem")
+	filteredtarfile := createTmpFile(t, folder, "filtered.tar.gz")
+	filtereddebfile := createTmpFile(t, folder, "filtered.deb")
 
 	config := config.Project{
 		Dist: folder,
@@ -50,7 +51,7 @@ func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Type: artifact.UploadableArchive,
 		Name: "bin.tar.gz",
-		Path: tarfile.Name(),
+		Path: tarfile,
 		Extra: map[string]interface{}{
 			artifact.ExtraID: "foo",
 		},
@@ -58,7 +59,7 @@ func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Type: artifact.LinuxPackage,
 		Name: "bin.deb",
-		Path: debfile.Name(),
+		Path: debfile,
 		Extra: map[string]interface{}{
 			artifact.ExtraID: "foo",
 		},
@@ -66,7 +67,7 @@ func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Type: artifact.UploadableArchive,
 		Name: "filtered.tar.gz",
-		Path: filteredtarfile.Name(),
+		Path: filteredtarfile,
 		Extra: map[string]interface{}{
 			artifact.ExtraID: "bar",
 		},
@@ -74,7 +75,7 @@ func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Type: artifact.LinuxPackage,
 		Name: "filtered.deb",
-		Path: filtereddebfile.Name(),
+		Path: filtereddebfile,
 		Extra: map[string]interface{}{
 			artifact.ExtraID: "bar",
 		},
@@ -82,11 +83,36 @@ func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Type: artifact.UploadableSourceArchive,
 		Name: "source.tar.gz",
-		Path: srcfile.Name(),
+		Path: srcfile,
 		Extra: map[string]interface{}{
 			artifact.ExtraFormat: "tar.gz",
 		},
 	})
+
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Type: artifact.Checksum,
+		Name: "checksum",
+		Path: checksumfile,
+		Extra: map[string]interface{}{
+			artifact.ExtraID: "bar",
+		},
+	})
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Type: artifact.Signature,
+		Name: "checksum.sig",
+		Path: checksumsigfile,
+		Extra: map[string]interface{}{
+			artifact.ExtraID: "bar",
+		},
+	})
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Type: artifact.Certificate,
+		Name: "checksum.pem",
+		Path: checksumpemfile,
+		Extra: map[string]interface{}{
+			artifact.ExtraID: "bar",
+		},
+	})
 	client := &client.Mock{}
 	require.NoError(t, doPublish(ctx, client))
 	require.True(t, client.CreatedRelease)
@@ -96,6 +122,9 @@ func TestRunPipeWithoutIDsThenDoesNotFilter(t *testing.T) {
 	require.Contains(t, client.UploadedFileNames, "bin.tar.gz")
 	require.Contains(t, client.UploadedFileNames, "filtered.deb")
 	require.Contains(t, client.UploadedFileNames, "filtered.tar.gz")
+	require.Contains(t, client.UploadedFileNames, "checksum")
+	require.Contains(t, client.UploadedFileNames, "checksum.pem")
+	require.Contains(t, client.UploadedFileNames, "checksum.sig")
 }
 
 func TestRunPipeWithIDsThenFilters(t *testing.T) {
@@ -317,9 +346,12 @@ func TestDefault(t *testing.T) {
 
 	ctx := context.New(config.Project{})
 	ctx.TokenType = context.TokenTypeGitHub
+	ctx.Config.GitHubURLs.Download = "https://github.com"
+	ctx.Git.CurrentTag = "v1.0.0"
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, "goreleaser", ctx.Config.Release.GitHub.Name)
 	require.Equal(t, "goreleaser", ctx.Config.Release.GitHub.Owner)
+	require.Equal(t, "https://github.com/goreleaser/goreleaser/releases/tag/v1.0.0", ctx.ReleaseURL)
 }
 
 func TestDefaultWithGitlab(t *testing.T) {
@@ -329,9 +361,12 @@ func TestDefaultWithGitlab(t *testing.T) {
 
 	ctx := context.New(config.Project{})
 	ctx.TokenType = context.TokenTypeGitLab
+	ctx.Config.GitLabURLs.Download = "https://gitlab.com"
+	ctx.Git.CurrentTag = "v1.0.0"
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, "gitlabrepo", ctx.Config.Release.GitLab.Name)
 	require.Equal(t, "gitlabowner", ctx.Config.Release.GitLab.Owner)
+	require.Equal(t, "https://gitlab.com/gitlabowner/gitlabrepo/-/releases/v1.0.0", ctx.ReleaseURL)
 }
 
 func TestDefaultWithGitea(t *testing.T) {
@@ -341,16 +376,52 @@ func TestDefaultWithGitea(t *testing.T) {
 
 	ctx := context.New(config.Project{})
 	ctx.TokenType = context.TokenTypeGitea
+	ctx.Config.GiteaURLs.Download = "https://git.honk.com"
+	ctx.Git.CurrentTag = "v1.0.0"
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, "gitearepo", ctx.Config.Release.Gitea.Name)
 	require.Equal(t, "giteaowner", ctx.Config.Release.Gitea.Owner)
+	require.Equal(t, "https://git.honk.com/giteaowner/gitearepo/releases/tag/v1.0.0", ctx.ReleaseURL)
 }
 
-func TestDefaultPreReleaseAuto(t *testing.T) {
+func TestDefaultPreRelease(t *testing.T) {
 	testlib.Mktmp(t)
 	testlib.GitInit(t)
 	testlib.GitRemoteAdd(t, "git@github.com:goreleaser/goreleaser.git")
 
+	t.Run("prerelease", func(t *testing.T) {
+		ctx := context.New(config.Project{
+			Release: config.Release{
+				Prerelease: "true",
+			},
+		})
+		ctx.TokenType = context.TokenTypeGitHub
+		ctx.Semver = context.Semver{
+			Major: 1,
+			Minor: 0,
+			Patch: 0,
+		}
+		require.NoError(t, Pipe{}.Default(ctx))
+		require.True(t, ctx.PreRelease)
+	})
+
+	t.Run("release", func(t *testing.T) {
+		ctx := context.New(config.Project{
+			Release: config.Release{
+				Prerelease: "false",
+			},
+		})
+		ctx.TokenType = context.TokenTypeGitHub
+		ctx.Semver = context.Semver{
+			Major:      1,
+			Minor:      0,
+			Patch:      0,
+			Prerelease: "rc1",
+		}
+		require.NoError(t, Pipe{}.Default(ctx))
+		require.False(t, ctx.PreRelease)
+	})
+
 	t.Run("auto-release", func(t *testing.T) {
 		ctx := context.New(config.Project{
 			Release: config.Release{
